<?php
/*
Plugin Name: Advanced Featured Post Widget
Plugin URI: http://wasistlos.waldemarstoffel.com/plugins-fur-wordpress/advanced-featured-post-widget
Description: The Advanced Featured Post Widget is yet another plugin to make your blog a bit more newspaper-like. Just by choosing a post from the dropdown menu, you can put it in the 'featured' area and display thumbnail, headline, excerpt or all three of them (if available) in the fully customizable widget. It just has more options than the the Featured Post Widget.
Version: 2.6
Author: Waldemar Stoffel
Author URI: http://www.waldemarstoffel.com
License: GPL3
Text Domain: advanced-fpw
*/

/*  Copyright 2011  Waldemar Stoffel  (email : w-stoffel@gmx.net)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/


/* Stop direct call */

if(preg_match('#' . basename(__FILE__) . '#', $_SERVER['PHP_SELF'])) die('Sorry, you don&#39;t have direct access to this page.');

define( 'AFPW_PATH', plugin_dir_path(__FILE__) );

if (!class_exists('A5_Thumbnail')) require_once AFPW_PATH.'class-lib/A5_ImageClasses.php';
if (!class_exists('A5_Excerpt')) require_once AFPW_PATH.'class-lib/A5_ExcerptClass.php';
if (!class_exists('A5_WidgetControlClass')) require_once AFPW_PATH.'class-lib/A5_WidgetControlClass.php';
if (!class_exists('Advanced_Featured_Post_Widget')) require_once AFPW_PATH.'class-lib/AFPW_WidgetClass.php';

class Advanced_FPW {
	
	const language_file = 'advanced-fpw';
	
	function Advanced_FPW() {
		
		// import laguage files
	
		load_plugin_textdomain(self::language_file, false , basename(dirname(__FILE__)).'/languages');

		add_action('admin_enqueue_scripts', array($this, 'afpw_js_sheet'));
		add_filter('plugin_row_meta', array($this, 'afpw_register_links'),10,2);
		add_filter( 'plugin_action_links', array($this, 'afpw_plugin_action_links'), 10, 2 );
		add_action('admin_init', array($this, 'afpw_init'));
		register_activation_hook(  __FILE__, array($this, 'install_afpw') );
		register_deactivation_hook(  __FILE__, array($this, 'unset_afpw') );
		add_action('admin_menu', array($this, 'afpw_admin_menu'));
		add_action('init', array($this, 'afpw_add_rewrite'));
		add_action('template_redirect', array($this, 'afpw_css_template'));
		add_action ('wp_enqueue_scripts', array($this, 'afpw_css'));
		
	}

	/* attach JavaScript file for textarea resizing */
	
	function afpw_js_sheet($hook) {
		
		if ($hook != 'settings_page_advanced-fpw-settings' && $hook != 'widgets.php') return;
		
		wp_register_script('ta-expander-script', plugins_url('ta-expander.js', __FILE__), array('jquery'), '2.0', true);
		wp_enqueue_script('ta-expander-script');
	
	}
	
	//Additional links on the plugin page
	
	function afpw_register_links($links, $file) {
		
		$base = plugin_basename(__FILE__);
		
		if ($file == $base) :
			
			$links[] = '<a href="http://wordpress.org/extend/plugins/advanced-featured-post-widget/faq/" target="_blank">'.__('FAQ', self::language_file).'</a>';
			$links[] = '<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=4P2ACVGPHY7WU" target="_blank">'.__('Donate', self::language_file).'</a>';
		
		endif;
		
		return $links;
	
	}
	
	function afpw_plugin_action_links( $links, $file ) {
		
		$base = plugin_basename(__FILE__);
		
		if ($file == $base) array_unshift($links, '<a href="'.admin_url( 'options-general.php?page=advanced-fpw-settings' ).'">'.__('Settings', self::language_file).'</a>');
	
		return $links;
	
	}
	
	// init
	
	function afpw_init() {
		
		register_setting( 'afpw_options', 'afpw_options', array($this, 'afpw_validate') );
		
		add_settings_section('afpw_settings', __('Styling of the links', self::language_file), array($this, 'afpw_display_section'), 'afpw_styles');
		
		add_settings_field('afpw_link_style', __('Link style:', self::language_file), array($this, 'afpw_link_field'), 'afpw_styles', 'afpw_settings');
		
		add_settings_field('afpw_hover_style', __('Hover style:', self::language_file), array($this, 'afpw_hover_field'), 'afpw_styles', 'afpw_settings');
	
	}
	
	function afpw_display_section() {
		
		echo '<p>'.__('Just put some css code here.', self::language_file).'</p>';
	
	}
	
	function afpw_link_field() {
		
		$afpw_options = get_option('afpw_options');
		
		echo '<textarea id="afpw_link" name="afpw_options[link]" cols="35">'.$afpw_options['link'].'</textarea>';
		
	}
	
	function afpw_hover_field() {
		
		$afpw_options = get_option('afpw_options');
		
		echo '<textarea id="afpw_hover" name="afpw_options[hover]" cols="35">'.$afpw_options['hover'].'</textarea>';
		
	}
	
	// Creating default options on activation
	
	function install_afpw() {
		
		$default = array(
			'tags' => array(),
			'sizes' => array()
		);
		
		add_option('afpw_options', $default);
		
	}	
	
	// Cleaning on deactivation
	
	function unset_afpw() {
		
		delete_option('afpw_options');
		
	}
	
	// Installing options page
	
	function afpw_admin_menu() {
		
		add_options_page(__('Advanced FP Settings', self::language_file), 'Advanced Featured Post Widget', 'administrator', 'advanced-fpw-settings', array($this, 'advanced_fpw_options_page'));
		
	}
	
	// Calling the options page
	
	function advanced_fpw_options_page() {
		
		?>
		
		<div>
		<h2><?php _e('Advanced Featured Post Widget Settings', self::language_file); ?></h2>
		<?php settings_errors(); ?>
		<?php _e('Style the links of the widget. If you leave this empty, your theme will style the hyperlinks.', self::language_file); ?>
		<p><?php _e('Just input something like,', self::language_file); ?>
		<p><strong>font-weight: bold;<br />
		color: #0000ff;<br />
		text-decoration: underline;    
		</strong></p>
		<?php _e('to get fat, blue, underlined links.', self::language_file); ?></p>
		<p><strong><?php _e('You most probably have to use &#34;!important&#34; at the end of each line, to make it work.', self::language_file); ?></strong></p>
		
		<form action="options.php" method="post">
		
		<?php
		
		settings_fields('afpw_options');
		do_settings_sections('afpw_styles');
		
		?>
		
		<input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
		</form></div>
		<script type="text/javascript"><!--
	jQuery(document).ready(function() {
		jQuery("#afpw_link").autoResize();
		jQuery("#afpw_hover").autoResize();
	});
	--></script>
		<?php
	}
	
	function afpw_validate($input) {
		
		$afpw_options = get_option('afpw_options');
		
		$newinput['link']=trim($input['link']);
		$newinput['hover']=trim($input['hover']);
		$newinput['tags']=$afpw_options['tags'];
		$newinput['sizes']=$afpw_options['sizes'];
		
		return $newinput;
	
	}
	
	function afpw_add_rewrite() {
		   global $wp;
		   $wp->add_query_var('afpwfile');
	}
	
	function afpw_css_template() {
		   if (get_query_var('afpwfile') == 'css') {
				   
				   header('Content-type: text/css');
				   echo $this->afpw_write_css();
				   
				   exit;
		   }
	}
	
	function afpw_css () {
		
		$afpw_options = get_option('afpw_options');
		
		if (!empty ($afpw_options['link']) || !empty ($afpw_options['hover'])) :		
			
			$afpw_css_file=get_bloginfo('url').'/?afpwfile=css';
			
			wp_register_style('advanced-fpw', $afpw_css_file, false, '2.4', 'all');
			wp_enqueue_style('advanced-fpw');
				
		endif;
		
	}
	
	// writing css file
		
	function afpw_write_css() {
		
		$afpw_styles=get_option('afpw_options');
		
		$eol = "\r\n";
		
		$css_text='@charset "UTF-8";'.$eol.'/* CSS Document */'.$eol.$eol;
		
		if (!empty($afpw_styles['link'])) {
				   
				   $afpw_link=str_replace(array("\r\n", "\n", "\r"), ' ', $afpw_styles['link']);
				   $css_text.='.afpwlink {'.$afpw_link.'}'.$eol;
				   
		}
				   
		if (!empty($afpw_styles['hover'])) {
				   
				   $afpw_hover=str_replace(array("\r\n", "\n", "\r"), ' ', $afpw_styles['hover']);
				   $css_text.='.afpwlink:hover {'.$afpw_hover.'}';
				   
		}
		
		return $css_text;
		
	}

}

$advancedfpw = new Advanced_FPW;

?>